@@ -14,6 +14,7 @@ import importlib.metadata
 import importlib.resources
 import importlib.util
 import inspect
+import itertools
 import operator
 import os
 import packaging.version
@@ -147,7 +148,6 @@ def main():
     print('Initializing the template resources...')
     # Collect the init.py files to be executed, and the relative names of the
     # folders they are in.
-    # TODO path is incorrect
     baseFolder = os.path.join(baseDirectory, 'manuscripts')
     fileList = []
     for filename in glob.glob(f'{baseFolder}/**/init.py', recursive = True):
@@ -156,14 +156,12 @@ def main():
       fileList.append((folder, scriptname))
 
     # Get the number of CPUs for parallel processing.
-    nCpu = cpu_count()
+    nCPU = cpu_count()
 
     # Execute all scripts in parallel (by calling the init function) and catch
     # their return values.
-    from IPython import embed
-    embed()
-    with Pool(nCpu) as p:
-      returnValues = p.map(init, fileList, baseDirectory)
+    with Pool(nCPU) as p:
+      returnValues = p.starmap(init, zip(fileList, itertools.cycle([baseDirectory])))
 
       # Filter the return values for failed scripts.
       failedList = [(x[1], x[2], x[3]) for x in returnValues if not x[0]]
