@@ -6,7 +6,7 @@
 
 import os
 import sys
-import utilities
+from ste.utilities import utilities
 from subprocess import run, STDOUT
 
 if __name__ == '__main__':
