@@ -6,7 +6,7 @@
 # https://bmcbioinformatics.biomedcentral.com/submission-guidelines/preparing-your-manuscript
 
 import sys
-import utilities
+from ste.utilities import utilities
 
 if __name__ == '__main__':
   try:
