@@ -6,7 +6,7 @@
 
 import re
 import sys
-import utilities
+from ste.utilities import utilities
 
 if __name__ == '__main__':
   try:
