@@ -6,7 +6,7 @@
 # https://www.springernature.com/gp/authors/campaigns/latex-author-support
 
 import sys
-import utilities
+from ste.utilities import utilities
 
 if __name__ == '__main__':
   try:
