@@ -5,7 +5,7 @@
 # https://www.springer.com/journal/245/submission-guidelines 
 
 import sys
-import utilities
+from ste.utilities import utilities
 
 if __name__ == '__main__':
   try:
