@@ -2,7 +2,7 @@
 
 # Resolve the dependencies.
 import collections
-import copy
+import glob
 import itertools
 import numpy as np
 import os
@@ -15,7 +15,6 @@ from scipy import optimize
 class parserObject(object):
 
   def __init__(self, parserInfo):
-
     # Initialize the data structure.
     self.authors = parserInfo.dataFileData.get("authors", []) or []
     self.institutions = parserInfo.dataFileData.get("institutions", {}) or {}
@@ -314,19 +313,16 @@ class parserObject(object):
     outname = os.path.basename(fp.name)
 
     # Invoke scoop-template-engine.py recursively with the same command line arguments plus '--prefix random --template bibgenerator --quiet'.
-    # TODO replace subprocess.run
-    args = copy.deepcopy(sys.argv)
+    args = sys.argv.copy()
     args.append('--prefix')
     args.append(outname)
     args.append('--template')
     args.append('bibgenerator')
     args.append('--quiet')
-    #  commandString = (self.thisScriptAbsolutePathCallSummary + " --prefix {outname:s} --template bibgenerator --quiet").format(outname = outname)
     returnValue = subprocess.run(args)
     
     # Run pdflatex once on the generated file, suppressing the output.
-    # TODO join paths
-    texFileNameStub = "/".join(filter(None, [self.outDirectory, outname + '-bibgenerator']))
+    texFileNameStub = os.path.join(self.outDirectory, outname + '-bibgenerator')
     texFileName = texFileNameStub + ".tex"
     commandString = "pdflatex -interaction nonstopmode -output-directory " + self.outDirectory + " " + texFileName 
     returnValue = subprocess.run(commandString, shell = True, stdout = subprocess.DEVNULL)
@@ -336,10 +332,8 @@ class parserObject(object):
       print('WARNING: {commandString:s} failed.\n'.format(commandString = commandString), file = sys.stderr)
 
     # Invoke scoop-prepare-bibtex-file.py on the generated .bcf file, provided it is non-empty.
-    # TODO join paths
-    # TODO replace subprocess.run
-    bcfFileName = re.sub('.tex$', '.bcf', texFileName)
-    bibFileName = "/".join(filter(None, [self.outDirectory, re.sub('.tex$', '.bib', self.outFileBaseName)]))
+    bcfFileName = texFileNameStub + ".bcf"
+    bibFileName = os.path.join(self.outDirectory, re.sub('.tex$', '.bib', self.outFileBaseName))
     commandString = "spbf " + bcfFileName + " " + self.customBibliographySwitches
     with open(bibFileName, "w") as bibFileStream:
       returnValue = subprocess.run(commandString, shell = True, stdout = bibFileStream)
@@ -349,7 +343,6 @@ class parserObject(object):
       print('WARNING: {commandString:s} failed.\n'.format(commandString = commandString), file = sys.stderr)
 
     # Remove temporary files.
-    import glob
     fp.close()
     fileList = glob.glob(texFileNameStub + ".*")
     for filePath in fileList:
